@@ -56,7 +56,7 @@ void TestBackendLoader::testPreferredBackend()
     auto backends = BackendManager::instance()->listBackends();
     QVERIFY(!backends.isEmpty());
     auto preferred = BackendManager::instance()->preferredBackend();
-    QVERIFY(preferred.exists());
+    QVERIFY(!preferred.isFile());
     auto fake = BackendManager::instance()->preferredBackend(QStringLiteral("Fake"));
     QVERIFY(fake.fileName().startsWith(QLatin1String("KSC_Fake")));
 }
@@ -72,8 +72,6 @@ void TestBackendLoader::testEnv_data()
     QTest::newRow("all upper") << "KWAYLAND" << "KSC_KWayland";
     QTest::newRow("mixed") << "kwAYlaND" << "KSC_KWayland";
 
-    QTest::newRow("xrandr 1.1") << "xrandr11" << "KSC_XRandR11";
-    QTest::newRow("qscreen") << "qscreen" << "KSC_QScreen";
     QTest::newRow("mixed") << "fake" << "KSC_Fake";
     // clang-format on
 }
@@ -92,7 +90,7 @@ void TestBackendLoader::testFallback()
 {
     qputenv("KSCREEN_BACKEND", "nonsense");
     auto preferred = BackendManager::instance()->preferredBackend();
-    QVERIFY(preferred.fileName().startsWith(QLatin1String("KSC_QScreen")));
+    QVERIFY(!preferred.isFile());
 }
 
 QTEST_GUILESS_MAIN(TestBackendLoader)
