@@ -5,7 +5,8 @@
  */
 
 #include <QObject>
-#include <QtTest>
+#include <QSignalSpy>
+#include <QTest>
 
 #include "../src/backendmanager_p.h"
 #include "../src/config.h"
