@@ -10,7 +10,9 @@
 #include <QSize>
 #include <QVariant>
 
-#include "../xcbwrapper.h"
+#include <xcb/randr.h>
+#include <xcb/xcb.h>
+
 #include "types.h"
 
 class XRandROutput;
@@ -43,5 +45,3 @@ private:
     QSize m_size;
     float m_refreshRate;
 };
-
-Q_DECLARE_METATYPE(XRandRMode::Map)
